==> dde-dock_4.7.3.2.orig.tar.xz: translations/dde-dock_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>ContainerItem</name>
    <message>
        <location filename="../frame/item/containeritem.cpp" line="33"/>
        <source>Click to display hidden icon</source>
        <translation>Kattintson a rejtett ikon megjelenítéséhez</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="55"/>
        <source>Datetime</source>
        <translation>Dátum és idő</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="119"/>
        <source>12 Hour Time</source>
        <translation>12 órás idő</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="121"/>
        <source>24 Hour Time</source>
        <translation>24 órás idő</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="127"/>
        <source>Time Settings</source>
        <translation>Idő beállítás</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="51"/>
        <source>Enable network</source>
        <translation>Hálózat engedélyezése</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="53"/>
        <source>Disable network</source>
        <translation>Hálózat letiltása</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="59"/>
        <source>Network settings</source>
        <translation>Hálózati beállítások</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="106"/>
        <source>Unknown device</source>
        <translation>Ismeretlen eszköz</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="112"/>
        <source>Unknown volume</source>
        <translation>Ismeretlen kötet</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="40"/>
        <source>Disk</source>
        <translation>Lemez</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="90"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="96"/>
        <source>Unmount all</source>
        <translation>Minden külső partíció leválasztása</translation>
    </message>
</context>
<context>
    <name>DockSettings</name>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="46"/>
        <source>Fashion Mode</source>
        <translation>Stílus mód</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="47"/>
        <source>Efficient Mode</source>
        <translation>Hatékony mód</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="48"/>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="49"/>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="50"/>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="51"/>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="52"/>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="53"/>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="54"/>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="55"/>
        <source>Keep Shown</source>
        <translation>Megjelenítve tartás</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="56"/>
        <source>Keep Hidden</source>
        <translation>Elrejtve tartás</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="57"/>
        <source>Smart Hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="94"/>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="102"/>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="109"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="116"/>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="120"/>
        <source>Plugins</source>
        <translation>Bővítmények</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <location filename="../frame/item/launcheritem.cpp" line="38"/>
        <source>Launcher</source>
        <translation>Indító</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <location filename="../plugins/network/networkplugin.cpp" line="46"/>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
</context>
<context>
    <name>PopupControlWidget</name>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="88"/>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="88"/>
        <source>Empty</source>
        <translation>Üres</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="93"/>
        <source>This action cannot be restored</source>
        <translation>Ezt a műveletet nem lehet visszaállítani</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="95"/>
        <source>Are you sure to empty 1 item ?</source>
        <translation>Biztosan ürítsük ezt az 1 elemet?</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="97"/>
        <source>Are you sure to empty %1 items ?</source>
        <translation>Biztosan ürítsük ezt az %1 elemet?</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="78"/>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="148"/>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="86"/>
        <source>Remaining Capacity %1</source>
        <translation>Hátralevő kapacitás %1</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="92"/>
        <source>Charged %1</source>
        <translation>Töltve %1</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="94"/>
        <source>Charging %1</source>
        <translation>Töltés %1</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="154"/>
        <source>Restart</source>
        <translation>Újraindítás </translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="166"/>
        <source>Lock</source>
        <translation>Zárolás</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="172"/>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="160"/>
        <source>Suspend</source>
        <translation>Felfüggesztés</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="58"/>
        <source>Power</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="180"/>
        <source>Switch account</source>
        <translation>Felhasználóváltás</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="190"/>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="56"/>
        <source>Device</source>
        <translation>Eszköz</translation>
    </message>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="75"/>
        <source>Application</source>
        <translation>Alkalmazás</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="79"/>
        <source>Unmute</source>
        <translation>Elnémítás törlése</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="81"/>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="87"/>
        <source>Audio Settings</source>
        <translation>Hangeszköz beállítások</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="215"/>
        <source>Current Volume %1</source>
        <translation>Jelenlegi hangerő %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <location filename="../plugins/sound/soundplugin.cpp" line="41"/>
        <source>Sound</source>
        <translation>Hang</translation>
    </message>
</context>
<context>
    <name>SystemTrayPlugin</name>
    <message>
        <location filename="../plugins/system-tray/systemtrayplugin.cpp" line="46"/>
        <source>System Tray</source>
        <translation>Rendszertálca</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="61"/>
        <source>Trash - %1 file</source>
        <translation>Kukában: %1 fájl</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="63"/>
        <source>Trash - %1 files</source>
        <translation>Kukában: %1 fájl</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="65"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="73"/>
        <source>Empty</source>
        <translation>Üres</translation>
    </message>
</context>
<context>
    <name>WiredItem</name>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="68"/>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="73"/>
        <source>No Network</source>
        <translation>Nincs hálózat</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="83"/>
        <source>Wired connection: %1</source>
        <translation>Vezetékes kapcsolat: %1</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <location filename="../plugins/network/item/wirelessitem.cpp" line="75"/>
        <source>No Network</source>
        <translation>Nincs hálózat</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wirelessitem.cpp" line="85"/>
        <source>Wireless Connection: %1</source>
        <translation>Vezeték nélküli kapcsolat: %1</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="55"/>
        <source>Auto-connect</source>
        <translation>Automatikus csatlakozás</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="67"/>
        <source>Connect</source>
        <translation>Csatlakozás</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="68"/>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="174"/>
        <source>Wireless Network</source>
        <translation>Vezeték nélküli hálózat</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="176"/>
        <source>Wireless Network %1</source>
        <translation>Vezeték nélküli Hálózat %1 </translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="432"/>
        <source>Password required to connect to &lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt;</source>
        <translation>&lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt; kapcsolathoz jelszó szükséges.</translation>
    </message>
</context>
</TS>

==> dde-dock_4.9.1.1.orig.tar.xz: translations/dde-dock_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>ContainerItem</name>
    <message>
        <location filename="../frame/item/containeritem.cpp" line="33"/>
        <source>Click to display hidden icon</source>
        <translation>Kattintson a rejtett ikon megjelenítéséhez</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <location filename="../plugins/keyboard-layout/dbusadaptors.cpp" line="138"/>
        <source>Add keyboard layout</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="57"/>
        <source>Datetime</source>
        <translation>Dátum és idő</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="146"/>
        <source>12 Hour Time</source>
        <translation>12 órás idő</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="148"/>
        <source>24 Hour Time</source>
        <translation>24 órás idő</translation>
    </message>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="154"/>
        <source>Time Settings</source>
        <translation>Idő beállítás</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="59"/>
        <source>Enable network</source>
        <translation>Hálózat engedélyezése</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="61"/>
        <source>Disable network</source>
        <translation>Hálózat letiltása</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/deviceitem.cpp" line="67"/>
        <source>Network settings</source>
        <translation>Hálózati beállítások</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="88"/>
        <source>Are you sure to empty %1 items?</source>
        <translation>Biztosan töröljük ezt az %1 elemet?</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="93"/>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="93"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="113"/>
        <source>This action cannot be restored</source>
        <translation>Ezt a műveletet nem lehet visszaállítani</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="106"/>
        <source>Unknown device</source>
        <translation>Ismeretlen eszköz</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="112"/>
        <source>Unknown volume</source>
        <translation>Ismeretlen kötet</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="40"/>
        <source>Disk</source>
        <translation>Lemez</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="90"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="96"/>
        <source>Unmount all</source>
        <translation>Minden külső partíció leválasztása</translation>
    </message>
</context>
<context>
    <name>DockPluginsController</name>
    <message>
        <location filename="../frame/controller/dockpluginscontroller.cpp" line="157"/>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DockSettings</name>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="47"/>
        <source>Fashion Mode</source>
        <translation>Stílus mód</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="48"/>
        <source>Efficient Mode</source>
        <translation>Hatékony mód</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="49"/>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="50"/>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="51"/>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="52"/>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="53"/>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="54"/>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="55"/>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="56"/>
        <source>Keep Shown</source>
        <translation>Megjelenítve tartás</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="57"/>
        <source>Keep Hidden</source>
        <translation>Elrejtve tartás</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="58"/>
        <source>Smart Hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="94"/>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="102"/>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="109"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="116"/>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="120"/>
        <source>Plugins</source>
        <translation>Bővítmények</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <location filename="../frame/item/launcheritem.cpp" line="105"/>
        <source>Launcher</source>
        <translation>Indító</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <location filename="../plugins/network/networkplugin.cpp" line="49"/>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <location filename="../plugins/onboard/onboardplugin.cpp" line="35"/>
        <location filename="../plugins/onboard/onboardplugin.cpp" line="46"/>
        <source>Onboard</source>
        <translation>Virtuális billentyűzet</translation>
    </message>
    <message>
        <location filename="../plugins/onboard/onboardplugin.cpp" line="106"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="46"/>
        <source>Power</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="71"/>
        <source>Remaining Capacity %1</source>
        <translation>Hátralevő kapacitás %1</translation>
    </message>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="76"/>
        <source>Charged %1</source>
        <translation>Töltve %1</translation>
    </message>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="78"/>
        <source>Charging %1</source>
        <translation>Töltés %1</translation>
    </message>
    <message>
        <location filename="../plugins/power/powerplugin.cpp" line="132"/>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="117"/>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="123"/>
        <source>Restart</source>
        <translation>Újraindítás </translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="136"/>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="143"/>
        <source>Lock</source>
        <translation>Zárolás</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="149"/>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="129"/>
        <source>Suspend</source>
        <translation>Felfüggesztés</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="157"/>
        <source>Switch account</source>
        <translation>Felhasználóváltás</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="164"/>
        <source>Power settings</source>
        <translation>Energiagazdálkodási beállítások</translation>
    </message>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="46"/>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="62"/>
        <source>Shutdown</source>
        <translation>Leállítás</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="54"/>
        <source>Device</source>
        <translation>Eszköz</translation>
    </message>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="72"/>
        <source>Application</source>
        <translation>Alkalmazás</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="78"/>
        <source>Unmute</source>
        <translation>Némítás visszavonása</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="80"/>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="86"/>
        <source>Audio Settings</source>
        <translation>Hangeszköz beállítások</translation>
    </message>
    <message>
        <location filename="../plugins/sound/sounditem.cpp" line="207"/>
        <source>Current Volume %1</source>
        <translation>Jelenlegi hangerő %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <location filename="../plugins/sound/soundplugin.cpp" line="40"/>
        <source>Sound</source>
        <translation>Hang</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="52"/>
        <source>Trash</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="90"/>
        <source>Trash - %1 file</source>
        <translation>Kukában: %1 fájl</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashplugin.cpp" line="92"/>
        <source>Trash - %1 files</source>
        <translation>Kukában: %1 fájl</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="71"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="79"/>
        <source>Empty</source>
        <translation>Üres</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <location filename="../plugins/tray/trayplugin.cpp" line="59"/>
        <source>System Tray</source>
        <translation>Rendszertálca</translation>
    </message>
</context>
<context>
    <name>WiredItem</name>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="47"/>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="199"/>
        <source>Wired connection: %1</source>
        <translation>Vezetékes kapcsolat: %1</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <location filename="../plugins/network/item/wirelessitem.cpp" line="49"/>
        <source>No Network</source>
        <translation>Nincs hálózat</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wirelessitem.cpp" line="275"/>
        <source>Wireless Connection: %1</source>
        <translation>Vezeték nélküli kapcsolat: %1</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <location filename="../plugins/network/item/applet/wirelesslist.cpp" line="158"/>
        <source>Wireless Network</source>
        <translation>Vezeték nélküli hálózat</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelesslist.cpp" line="160"/>
        <source>Wireless Network %1</source>
        <translation>Vezeték nélküli Hálózat %1 </translation>
    </message>
</context>
</TS>
